@@ -1,6 +1,6 @@
 lag1.plot <-
 function(series, max.lag=1, corr=TRUE, smooth=TRUE, col=gray(.1), 
-         lwl=1, bgl ='white', box.col=8, ...){ 
+         lwl=1, bgl ='white', ltcol=1, box.col=8, ...){ 
    #
    as.ts = stats::as.ts
    par = graphics::par
@@ -24,7 +24,7 @@ function(series, max.lag=1, corr=TRUE, smooth=TRUE, col=gray(.1),
     lines(stats::lowess(ts.intersect(stats::lag(series,-h),series)[,1],
                  ts.intersect(stats::lag(series,-h),series)[,2]), col=2, lwd=lwl)
     if (corr==TRUE)
-    legend("topright", legend=round(a[h], digits=2), text.col=4, bg=bgl, adj=.25, cex = 0.85, box.col=box.col)
+    legend("topright", legend=round(a[h], digits=2), text.col=ltcol, bg=bgl, adj=.25, box.col=box.col)
    on.exit(par(old.par))
    }
 }
