@@ -1,6 +1,6 @@
 lag2.plot <-
-function(series1,series2,max.lag=0,corr=TRUE,smooth=TRUE,col=gray(.1),
-         lwl=1, bgl ='white', box.col=8, ...){ 
+function(series1, series2, max.lag=0, corr=TRUE, smooth=TRUE, col=gray(.1),
+         lwl=1, bgl ='white', ltcol=1, box.col=8, ...){ 
    #
    as.ts = stats::as.ts
    par = graphics::par
@@ -26,8 +26,9 @@ function(series1,series2,max.lag=0,corr=TRUE,smooth=TRUE,col=gray(.1),
     lines(stats::lowess(ts.intersect(stats::lag(series1,-h),series2)[,1],
                  ts.intersect(stats::lag(series1,-h),series2)[,2]), col=2, lwd=lwl)
     if (corr==TRUE)
-    legend("topright", legend=round(a[m1-h], digits=2), text.col=4, bg=bgl, adj=.25, cex = 0.85, box.col=box.col)             
+    legend("topright", legend=round(a[m1-h], digits=2), text.col=ltcol, bg=bgl, adj=.25, box.col=box.col)             
    on.exit(par(old.par))
    }
 }
 
+
